@@ -27,9 +27,10 @@ class ClientLoop(object):
         url = self.path_url("/list")
         res = self.request_url(url, json={})
         click.echo("serve, status_code:{} text:{}".format(res.status_code, res.text))
+        click.echo("serve, res:  cost:{}".format(res.elapsed.total_seconds()))
         j = res.json()
         with open(os.path.join(self.dir, ".serve.json"), 'w', encoding='utf-8') as f:
-            f.write(json.dumps(j, ensure_ascii=False))
+            f.write(json.dumps(j, ensure_ascii=False, indent=2))
         return j
     
     def check_res(self, res, prefix=""):
